@@ -24,8 +24,10 @@
 // Qt headers
 #ifdef USE_QTWEBKIT
 #include <QWebView>
+#include <QWebPage>
 #else
 #include <QWebEngineView>
+#include <QWebEnginePage>
 #endif
 #include <QAction>
 
@@ -55,6 +57,9 @@ public:
     ~KMarkdownView() override;
 
 public:
+#ifdef DEBUG_WEB
+    void inspectElement();
+#endif
     void copySelection();
     void copyLinkUrl();
     void saveLinkAs();
@@ -64,6 +69,7 @@ public:
     QPoint scrollPosition() const;
     void setScrollPosition(int x, int y);
     void renderPage(QPainter* painter, const QRect& clip);
+    void findText(const QString& text, WebPage::FindFlags findFlags = {});
 
 Q_SIGNALS:
     void copyTextEnabledChanged(bool enabled);
@@ -82,14 +88,19 @@ private:
 #endif
 
 private:
-#ifndef USE_QTWEBKIT
     KMarkdownViewPage* m_viewPage = nullptr;
-#endif
 
     KMarkdownHtmlView* const m_htmlView;
     KAbstractMarkdownSourceDocument* const m_sourceDocument;
 };
 
+#ifdef DEBUG_WEB
+inline void KMarkdownView::inspectElement()
+{
+    triggerPageAction(WebPage::InspectElement);
+}
+#endif
+
 inline void KMarkdownView::copySelection()
 {
     triggerPageAction(WebPage::Copy);
